@@ -155,7 +155,15 @@ static AtkRoleItem role_items [] =
   { ATK_ROLE_APPLICATION, N_("application")},
   { ATK_ROLE_AUTOCOMPLETE, N_("autocomplete")},
   { ATK_ROLE_EDITBAR, N_("edit bar")},
-  { ATK_ROLE_EMBEDDED, N_("embedded component")}
+  { ATK_ROLE_EMBEDDED, N_("embedded component")},
+  { ATK_ROLE_ENTRY, N_("entry")},
+  { ATK_ROLE_CHART, N_("chart")},
+  { ATK_ROLE_CAPTION, N_("caption")},
+  { ATK_ROLE_DOCUMENT_FRAME, N_("document frame")},
+  { ATK_ROLE_HEADING, N_("heading")},
+  { ATK_ROLE_PAGE, N_("page")},
+  { ATK_ROLE_SECTION, N_("section")},
+  { ATK_ROLE_REDUNDANT_OBJECT, N_("redundant object")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -224,6 +232,45 @@ static const gchar* atk_object_name_property_table_summary = "accessible-table-s
 static const gchar* atk_object_name_property_table_caption_object = "accessible-table-caption-object";
 static const gchar* atk_object_name_property_hypertext_num_links = "accessible-hypertext-nlinks";
 
+#ifdef G_OS_WIN32
+
+#undef ATK_LOCALEDIR
+
+#define ATK_LOCALEDIR get_atk_locale_dir()
+
+G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
+
+static char *
+get_atk_locale_dir (void)
+{
+  return g_win32_get_package_installation_subdirectory
+    (GETTEXT_PACKAGE, dll_name, "lib/locale");
+}
+
+#endif
+
+static void
+gettext_initialization (void)
+{
+#ifdef ENABLE_NLS
+  static gboolean gettext_initialized = FALSE;
+
+  if (!gettext_initialized)
+    {
+      const char *dir = g_getenv ("ATK_ALT_LOCALEDIR");
+
+      gettext_initialized = TRUE;
+      if (dir == NULL)
+        dir = ATK_LOCALEDIR;
+
+      bindtextdomain (GETTEXT_PACKAGE, dir);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+      bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+    }
+#endif
+}
+
 GType
 atk_object_get_type (void)
 {
@@ -290,6 +337,8 @@ atk_object_class_init (AtkObjectClass *klass)
   klass->visible_data_changed = NULL;
   klass->active_descendant_changed = NULL;
 
+  gettext_initialization ();
+
   g_object_class_install_property (gobject_class,
                                    PROP_NAME,
                                    g_param_spec_string (atk_object_name_property_name,
@@ -677,9 +726,10 @@ atk_object_get_role (AtkObject *accessible)
  * @accessible: an #AtkObject
  *
  * Gets the layer of the accessible.
- * DEPRECATED: use atk_component_get_layer instead!
  *
  * Returns: an #AtkLayer which is the layer of the accessible
+ *
+ * @Deprecated: Use atk_component_get_layer instead.
  **/
 AtkLayer
 atk_object_get_layer (AtkObject *accessible) 
@@ -701,11 +751,12 @@ atk_object_get_layer (AtkObject *accessible)
  *
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
- * DEPRECATED: use atk_component_get_mdi_zorder instead!
  *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
  * container.
+ *
+ * @Deprecated: Use atk_component_get_mdi_zorder instead.
  **/
 gint
 atk_object_get_mdi_zorder (AtkObject *accessible) 
@@ -964,6 +1015,29 @@ atk_implementor_ref_accessible (AtkImplementor *object)
   return accessible;
 }
 
+    	
+/**
+ * Get a list of properties applied to this object as a whole, as an #AtkAttributeSet consisting of 
+ * name-value pairs. As such these attributes may be considered weakly-typed properties or annotations, 
+ * as distinct from strongly-typed object data available via other get/set methods.
+ * Not all objects have explicit "name-value pair" #AtkAttributeSet properties.
+ * @Since ATK 1.12
+ */
+AtkAttributeSet *
+atk_object_get_attributes (AtkObject                  *accessible)
+{
+  AtkObjectClass *klass;
+
+  g_return_val_if_fail (ATK_IS_OBJECT (accessible), NULL);
+
+  klass = ATK_OBJECT_GET_CLASS (accessible);
+  if (klass->get_attributes)
+    return (klass->get_attributes) (accessible); 
+  else 
+    return NULL;
+	
+}
+
 static AtkRelationSet*
 atk_object_real_ref_relation_set (AtkObject *accessible)
 {
@@ -1284,23 +1358,6 @@ atk_role_get_name (AtkRole role)
   return name;
 }
 
-#ifdef G_OS_WIN32
-
-#undef ATK_LOCALEDIR
-
-#define ATK_LOCALEDIR get_atk_locale_dir()
-
-G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
-
-static char *
-get_atk_locale_dir (void)
-{
-  return g_win32_get_package_installation_subdirectory
-    (GETTEXT_PACKAGE, dll_name, "lib/locale");
-}
-
-#endif
-
 /**
  * atk_role_get_localized_name:
  * @role: The #AtkRole whose localized name is required
@@ -1314,23 +1371,8 @@ atk_role_get_localized_name (AtkRole role)
 {
   G_CONST_RETURN gchar *name;
   gint i;
-  static gboolean gettext_initialized = FALSE;
 
-#ifdef ENABLE_NLS
-  if (!gettext_initialized)
-    {
-      const char *dir = g_getenv ("ATK_ALT_LOCALEDIR");
-
-      gettext_initialized = TRUE;
-      if (dir == NULL)
-        dir = ATK_LOCALEDIR;
-
-      bindtextdomain (GETTEXT_PACKAGE, dir);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-      bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
-    }
-#endif
+  gettext_initialization ();
 
   for (i = 0; i < G_N_ELEMENTS (role_items); i++)
     {
